==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
var GetTileImageUriArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GetTileImageUriArgsDescriptionMetadata, _super);
    function GetTileImageUriArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GetTileImageUriArgsDescriptionMetadata.b = function (a) {
        if (GetTileImageUriArgsDescriptionMetadata.a == null) {
            GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
        }
        if (a.g(GetTileImageUriArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.c = function (a) {
        a.item("TileLevel", "Number:int");
        a.item("TilePositionX", "Number:int");
        a.item("TilePositionY", "Number:int");
        a.item("TileImageUri", "String");
    };
    GetTileImageUriArgsDescriptionMetadata.d = function (a) {
        GetTileImageUriArgsDescriptionMetadata.b(a);
        a.u("GetTileImageUriArgs", function () { return new GetTileImageUriArgsDescription(); });
        a.t("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.$t = markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
}(Base));
export { GetTileImageUriArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
var GetTileImageUriArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GetTileImageUriArgsDescriptionMetadata, _super);
    function GetTileImageUriArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GetTileImageUriArgsDescriptionMetadata.b = function (a) {
        if (GetTileImageUriArgsDescriptionMetadata.a == null) {
            GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
        }
        if (a.j(GetTileImageUriArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.c = function (a) {
        a.item("TileLevel", "Number:int");
        a.item("TilePositionX", "Number:int");
        a.item("TilePositionY", "Number:int");
        a.item("TileImageUri", "String");
    };
    GetTileImageUriArgsDescriptionMetadata.d = function (a) {
        GetTileImageUriArgsDescriptionMetadata.b(a);
        a.aa("GetTileImageUriArgs", function () { return new GetTileImageUriArgsDescription(); });
        a.z("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.$t = markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
}(Base));
export { GetTileImageUriArgsDescriptionMetadata };
